# AminoN
library to make a bots for amino
## Installation
```
pip install AminoN
```
## How to use it?
you can chek the lessions or my discord server to learn how to use it
##community
you can join with the programmers 
```
http://aminoapps.com/c/Djjjhggghff
```
###import
```
splax
```
#what need
you need install requests and json and urllib to open this library